jira\_select.functions package
==============================

Submodules
----------

jira\_select.functions.field\_by\_name module
---------------------------------------------

.. automodule:: jira_select.functions.field_by_name
    :members:
    :undoc-members:
    :show-inheritance:

jira\_select.functions.sprint\_name module
------------------------------------------

.. automodule:: jira_select.functions.sprint_name
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: jira_select.functions
    :members:
    :undoc-members:
    :show-inheritance:
